package com.ruoyi.web.controller.system;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.utils.StringUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BomanCamera;
import com.ruoyi.system.service.IBomanCameraService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 摄像机设备Controller
 * 
 * @author ruoyi
 * @date 2024-01-02
 */
@RestController
@RequestMapping("/system/camera")
public class BomanCameraController extends BaseController
{
    @Autowired
    private IBomanCameraService bomanCameraService;

    /**
     * 查询摄像机设备列表
     */
    @GetMapping("/list")
    public TableDataInfo list(BomanCamera bomanCamera)
    {
        if(StringUtils.isEmpty(bomanCamera.getIsPage()) || StringUtils.equals("Y",bomanCamera.getIsPage())){
            startPage();
        }
        List<BomanCamera> list = bomanCameraService.selectBomanCameraList(bomanCamera);
        return getDataTable(list);
    }

    /**
     * 导出摄像机设备列表
     */
    @PreAuthorize("@ss.hasPermi('system:camera:export')")
    @Log(title = "摄像机设备", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BomanCamera bomanCamera)
    {
        List<BomanCamera> list = bomanCameraService.selectBomanCameraList(bomanCamera);
        ExcelUtil<BomanCamera> util = new ExcelUtil<BomanCamera>(BomanCamera.class);
        util.exportExcel(response, list, "摄像机设备数据");
    }

    /**
     * 获取摄像机设备详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:camera:query')")
    @GetMapping(value = "/{cameraId}")
    public AjaxResult getInfo(@PathVariable("cameraId") Long cameraId)
    {
        return success(bomanCameraService.selectBomanCameraByCameraId(cameraId));
    }

    /**
     * 新增摄像机设备
     */
    @PreAuthorize("@ss.hasPermi('system:camera:add')")
    @Log(title = "摄像机设备", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BomanCamera bomanCamera)
    {
        return toAjax(bomanCameraService.insertBomanCamera(bomanCamera));
    }

    /**
     * 修改摄像机设备
     */
    @PreAuthorize("@ss.hasPermi('system:camera:edit')")
    @Log(title = "摄像机设备", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody BomanCamera bomanCamera)
    {
        return toAjax(bomanCameraService.updateBomanCamera(bomanCamera));
    }

    /**
     * 删除摄像机设备
     */
    @PreAuthorize("@ss.hasPermi('system:camera:remove')")
    @Log(title = "摄像机设备", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{cameraIds}")
    public AjaxResult remove(@PathVariable Long[] cameraIds)
    {
        return toAjax(bomanCameraService.deleteBomanCameraByCameraIds(cameraIds));
    }
}
