package com.ruoyi.web.controller.tourists;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.BomanTouristsNumber;
import com.ruoyi.system.service.IBomanTouristsNumberService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 记录浏览人数Controller
 * 
 * @author ruoyi
 * @date 2024-04-03
 */
@RestController
@RequestMapping("/system/number")
public class BomanTouristsNumberController extends BaseController
{
    @Autowired
    private IBomanTouristsNumberService bomanTouristsNumberService;

    /**
     * 查询记录浏览人数列表
     */
    @PreAuthorize("@ss.hasPermi('system:number:list')")
    @GetMapping("/list")
    public TableDataInfo list(BomanTouristsNumber bomanTouristsNumber)
    {
        startPage();
        List<BomanTouristsNumber> list = bomanTouristsNumberService.selectBomanTouristsNumberList(bomanTouristsNumber);
        return getDataTable(list);
    }

    /**
     * 导出记录浏览人数列表
     */
    @PreAuthorize("@ss.hasPermi('system:number:export')")
    @Log(title = "记录浏览人数", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, BomanTouristsNumber bomanTouristsNumber)
    {
        List<BomanTouristsNumber> list = bomanTouristsNumberService.selectBomanTouristsNumberList(bomanTouristsNumber);
        ExcelUtil<BomanTouristsNumber> util = new ExcelUtil<BomanTouristsNumber>(BomanTouristsNumber.class);
        util.exportExcel(response, list, "记录浏览人数数据");
    }

    /**
     * 获取记录浏览人数详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:number:query')")
    @GetMapping(value = "/{touristsId}")
    public AjaxResult getInfo(@PathVariable("touristsId") Long touristsId)
    {
        return success(bomanTouristsNumberService.selectBomanTouristsNumberByTouristsId(touristsId));
    }

    /**
     * 新增记录浏览人数
     */
    @PreAuthorize("@ss.hasPermi('system:number:add')")
    @Log(title = "记录浏览人数", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody BomanTouristsNumber bomanTouristsNumber)
    {
        return toAjax(bomanTouristsNumberService.insertBomanTouristsNumber(bomanTouristsNumber));
    }

    /**
     * 修改记录浏览人数
     */
    @PreAuthorize("@ss.hasPermi('system:number:edit')")
    @Log(title = "记录浏览人数", businessType = BusinessType.UPDATE)
    @PostMapping("/put")
    public AjaxResult edit(@RequestBody BomanTouristsNumber bomanTouristsNumber)
    {
        return toAjax(bomanTouristsNumberService.updateBomanTouristsNumber(bomanTouristsNumber));
    }

    /**
     * 删除记录浏览人数
     */
    @PreAuthorize("@ss.hasPermi('system:number:remove')")
    @Log(title = "记录浏览人数", businessType = BusinessType.DELETE)
	@GetMapping("/delete/{touristsIds}")
    public AjaxResult remove(@PathVariable Long[] touristsIds)
    {
        return toAjax(bomanTouristsNumberService.deleteBomanTouristsNumberByTouristsIds(touristsIds));
    }

    /**
     * 根据日期查询数据（返回总数）
     */
    @PreAuthorize("@ss.hasPermi('system:number:statistics')")
    @Log(title = "记录浏览人数", businessType = BusinessType.DELETE)
    @GetMapping("/statistics")
    public AjaxResult num(BomanTouristsNumber bomanTouristsNumber)
    {
        return bomanTouristsNumberService.num(bomanTouristsNumber);
    }
}
