package com.ruoyi.system.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.BomanCameraMapper;
import com.ruoyi.system.domain.BomanCamera;
import com.ruoyi.system.service.IBomanCameraService;

/**
 * 摄像机设备Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-01-02
 */
@Service
public class BomanCameraServiceImpl implements IBomanCameraService 
{
    @Autowired
    private BomanCameraMapper bomanCameraMapper;

    /**
     * 查询摄像机设备
     * 
     * @param cameraId 摄像机设备主键
     * @return 摄像机设备
     */
    @Override
    public BomanCamera selectBomanCameraByCameraId(Long cameraId)
    {
        return bomanCameraMapper.selectBomanCameraByCameraId(cameraId);
    }

    /**
     * 查询摄像机设备列表
     * 
     * @param bomanCamera 摄像机设备
     * @return 摄像机设备
     */
    @Override
    public List<BomanCamera> selectBomanCameraList(BomanCamera bomanCamera)
    {
        return bomanCameraMapper.selectBomanCameraList(bomanCamera);
    }

    /**
     * 新增摄像机设备
     * 
     * @param bomanCamera 摄像机设备
     * @return 结果
     */
    @Override
    public int insertBomanCamera(BomanCamera bomanCamera)
    {
        bomanCamera.setCreateTime(DateUtils.getNowDate());
        return bomanCameraMapper.insertBomanCamera(bomanCamera);
    }

    /**
     * 修改摄像机设备
     * 
     * @param bomanCamera 摄像机设备
     * @return 结果
     */
    @Override
    public int updateBomanCamera(BomanCamera bomanCamera)
    {
        bomanCamera.setUpdateTime(DateUtils.getNowDate());
        return bomanCameraMapper.updateBomanCamera(bomanCamera);
    }

    /**
     * 批量删除摄像机设备
     * 
     * @param cameraIds 需要删除的摄像机设备主键
     * @return 结果
     */
    @Override
    public int deleteBomanCameraByCameraIds(Long[] cameraIds)
    {
        return bomanCameraMapper.deleteBomanCameraByCameraIds(cameraIds);
    }

    /**
     * 删除摄像机设备信息
     * 
     * @param cameraId 摄像机设备主键
     * @return 结果
     */
    @Override
    public int deleteBomanCameraByCameraId(Long cameraId)
    {
        return bomanCameraMapper.deleteBomanCameraByCameraId(cameraId);
    }
}
