package com.ruoyi.system.service.impl;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.core.text.Convert;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.BomanReservat;
import com.ruoyi.system.mapper.BomanReservatMapper;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.BomanTouristsNumberMapper;
import com.ruoyi.system.domain.BomanTouristsNumber;
import com.ruoyi.system.service.IBomanTouristsNumberService;

/**
 * 记录浏览人数Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-04-03
 */
@Service
public class BomanTouristsNumberServiceImpl implements IBomanTouristsNumberService 
{
    @Autowired
    private BomanTouristsNumberMapper bomanTouristsNumberMapper;
    @Autowired
    private BomanReservatMapper bomanReservatMapper;

    @Autowired
    private static RedisCache redisCache;
    @Autowired
    public void setRedisCache(RedisCache redisCache) {
        BomanTouristsNumberServiceImpl.redisCache = redisCache;
    }

    /**
     * 查询记录浏览人数
     * 
     * @param touristsId 记录浏览人数主键
     * @return 记录浏览人数
     */
    @Override
    public BomanTouristsNumber selectBomanTouristsNumberByTouristsId(Long touristsId)
    {
        return bomanTouristsNumberMapper.selectBomanTouristsNumberByTouristsId(touristsId);
    }

    /**
     * 查询记录浏览人数列表
     * 
     * @param bomanTouristsNumber 记录浏览人数
     * @return 记录浏览人数
     */
    @Override
    public List<BomanTouristsNumber> selectBomanTouristsNumberList(BomanTouristsNumber bomanTouristsNumber)
    {
        return bomanTouristsNumberMapper.selectBomanTouristsNumberList(bomanTouristsNumber);
    }

    /**
     * 新增记录浏览人数
     * 
     * @param bomanTouristsNumber 记录浏览人数
     * @return 结果
     */
    @Override
    public int insertBomanTouristsNumber(BomanTouristsNumber bomanTouristsNumber)
    {
        bomanTouristsNumber.setCreateTime(DateUtils.getNowDate());
        return bomanTouristsNumberMapper.insertBomanTouristsNumber(bomanTouristsNumber);
    }

    /**
     * 修改记录浏览人数
     * 
     * @param bomanTouristsNumber 记录浏览人数
     * @return 结果
     */
    @Override
    public int updateBomanTouristsNumber(BomanTouristsNumber bomanTouristsNumber)
    {
        bomanTouristsNumber.setUpdateTime(DateUtils.getNowDate());
        return bomanTouristsNumberMapper.updateBomanTouristsNumber(bomanTouristsNumber);
    }

    /**
     * 批量删除记录浏览人数
     * 
     * @param touristsIds 需要删除的记录浏览人数主键
     * @return 结果
     */
    @Override
    public int deleteBomanTouristsNumberByTouristsIds(Long[] touristsIds)
    {
        return bomanTouristsNumberMapper.deleteBomanTouristsNumberByTouristsIds(touristsIds);
    }

    /**
     * 删除记录浏览人数信息
     * 
     * @param touristsId 记录浏览人数主键
     * @return 结果
     */
    @Override
    public int deleteBomanTouristsNumberByTouristsId(Long touristsId)
    {
        return bomanTouristsNumberMapper.deleteBomanTouristsNumberByTouristsId(touristsId);
    }

    @Override
    public AjaxResult num(BomanTouristsNumber bomanTouristsNumber) {
        Map<String,Object> map = new HashMap<>();
        //陵园参观人数
        List<BomanTouristsNumber> bomanTouristsNumberList = bomanTouristsNumberMapper.selectBomanTouristsNumberList(bomanTouristsNumber);
        Long cgNum = 0L;
        if(bomanTouristsNumberList!=null && bomanTouristsNumberList.size()>0){
            for (BomanTouristsNumber touristsNumber : bomanTouristsNumberList) {
                cgNum = cgNum + touristsNumber.getNumber();
            }
        }
        //获取当前时间
        String date = DateUtils.getDate();
        if(bomanTouristsNumber.getEndTime().compareTo(date)>=0){
            //当前
            String configKey = "lyssllsj";
            String configValue = Convert.toStr(redisCache.getCacheObject(configKey));
            if(StringUtils.isNotEmpty(configValue)){
                cgNum = cgNum + Long.valueOf(configValue);
            }
        }
        map.put("cgNum",cgNum);
        //查询预约的数据（单位数和人数）
        //单位数
        Long dwNum = 0L;
        Long yyNum = 0L;
        BomanReservat bomanReservat = new BomanReservat();
        bomanReservat.setStartTime(bomanTouristsNumber.getStartTime());
        bomanReservat.setEndTime(bomanTouristsNumber.getEndTime());
        List<BomanReservat> bomanReservats = bomanReservatMapper.selectBomanReservatList(bomanReservat);
        if(bomanReservats!=null && bomanReservats.size()>0){
            for (BomanReservat reservat : bomanReservats) {
                yyNum = yyNum + Long.valueOf(reservat.getVisitNum());
                if("1".equals(reservat.getReservatType())){
                    dwNum++;
                }
            }
        }
        map.put("dwNum",dwNum);
        map.put("yyNum",yyNum);
        return AjaxResult.success(map);
    }
}
